From: Greg KH <greg@kroah.com>
To: linux-kernel@vger.kernel.org, sensors@stimpy.netroedge.com
Subject: Re: [PATCH] I2C update for 2.6.7-rc1
Date: Fri, 28 May 2004 15:00:43 -0700 [thread overview]
Message-ID: <10857816431433@kroah.com> (raw)
In-Reply-To: <10857816431296@kroah.com>
ChangeSet 1.1717.6.29, 2004/05/28 13:47:51-07:00, khali@linux-fr.org
[PATCH] I2C: i2c-parport: support the ADM1031 evaluation board
The following patch adds support for the ADM1030 and ADM1031 evaluation
boards to the i2c-parport and i2c-parport-light drivers. They are almost
compatible with the already supported ADM1025 and ADM1032 boards, except
that the ADM1032 board needs some pins to be set high to draw its power,
while the same pins power up heating resistors on the ADM1031 board. I
considered it was a bit dangerous to do that by default, so I ended up
with two different device definitions, one with powering pins set, and
one with these pins cleared.
Signed-off-by: Greg Kroah-Hartman <greg@kroah.com>
drivers/i2c/busses/i2c-parport.h | 14 ++++++++++----
1 files changed, 10 insertions(+), 4 deletions(-)
diff -Nru a/drivers/i2c/busses/i2c-parport.h b/drivers/i2c/busses/i2c-parport.h
--- a/drivers/i2c/busses/i2c-parport.h Fri May 28 14:52:07 2004
+++ b/drivers/i2c/busses/i2c-parport.h Fri May 28 14:52:07 2004
@@ -67,13 +67,18 @@
.getsda = { 0x40, STAT, 1 },
.getscl = { 0x08, STAT, 1 },
},
- /* type 4: ADM1025 and ADM1032 evaluation boards */
+ /* type 4: ADM1032 evaluation board */
+ {
+ .setsda = { 0x02, DATA, 1 },
+ .setscl = { 0x01, DATA, 1 },
+ .getsda = { 0x10, STAT, 1 },
+ .init = { 0xf0, DATA, 0 },
+ },
+ /* type 5: ADM1025, ADM1030 and ADM1031 evaluation boards */
{
.setsda = { 0x02, DATA, 1 },
.setscl = { 0x01, DATA, 1 },
.getsda = { 0x10, STAT, 1 },
- .init = { 0xf0, DATA, 0 }, /* ADM1025 doesn't need this,
- but it doesn't hurt */
},
};
@@ -85,4 +90,5 @@
" 1 = home brew teletext adapter\n"
" 2 = Velleman K8000 adapter\n"
" 3 = ELV adapter\n"
- " 4 = ADM1025 and ADM1032 evaluation boards\n");
+ " 4 = ADM1032 evaluation board\n"
+ " 5 = ADM1025, ADM1030 and ADM1031 evaluation boards\n");
next prev parent reply other threads:[~2004-05-28 22:12 UTC|newest]
Thread overview: 9+ messages / expand[flat|nested] mbox.gz Atom feed top
2004-05-28 21:59 [BK PATCH] I2C update for 2.6.7-rc1 Greg KH
2004-05-28 22:00 ` [PATCH] " Greg KH
2004-05-28 22:00 ` Greg KH
2004-05-28 22:00 ` Greg KH
2004-05-28 22:00 ` Greg KH
2004-05-28 22:00 ` Greg KH
2004-05-28 22:00 ` Greg KH
2004-05-28 22:00 ` Greg KH [this message]
2004-05-28 22:00 ` Greg KH
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=10857816431433@kroah.com \
--to=greg@kroah.com \
--cc=linux-kernel@vger.kernel.org \
--cc=sensors@stimpy.netroedge.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox